==> psgresizer-1.0.1.tar.gz: psgresizer-1.0.1/README.md <==

<p align="center">
  <img src="https://raw.githubusercontent.com/PySimpleGUI/PySimpleGUI/master/images/for_readme/Logo%20with%20text%20for%20GitHub%20Top.png" alt="Python GUIs for Humans">
  <h2 align="center">psgresizer</h2>
  <h2 align="center">A PySimpleGUI Application</h2>

</p>

Resize your images quickly and easily with this GUI application.  Resizes and encodes to Base64 so that the result can be pasted into your PySimpleGUI program for easy distribution of your applications without the need to distribute image files.


![image](https://user-images.githubusercontent.com/46163555/138754708-baa27092-00c6-45bd-a7cc-4eca64de9eec.png)



## Installation

### Old-school Straight Pip

pip install psgresizer

### pip via `python -m pip` the python recommended way

#### If `python` is your command

python -m pip install psgresizer

#### If `python3` is your command

python3 -m pip install psgresizer

## Usage

Open a command window and type:   

`psgresizer`   


## Create a Shortcut To This Program

If you're a Windows user, then use the [`psgshortcut` application](https://pypi.org/project/psgshortcut/) to make a shortcut to this program so that you can then put on your desktop or pin to your taskbar (or any  other use that stops the need to type `psgresizer` ever again).

To get `psgshortcut`, like all of the other `psg application` projects, pip install it.  (e.g. `pip install psgshortcut`)



To do this, follow these steps:

1. Open a command window (I promise, it's the last time you'll need to for this program)
2. Type - `where psgresizer`
3. Copy the line that `where psgresizer` gave you into the first input of the shortcut maker program
4. Run psgresizer by typing `psgresizer` in your command window
5. Right click and choose "File Location"
6. Copy the file location results, but change the extension from .py to .ico and paste into the Icon file input of the shortcut maker
7. Click "Create Shortcut"

This will create a shortcut in the same folder as the target file.  You can safely move this shortcut file to any place you want (like to your desktop).  Double-click the shortcut and your program should launch.


## License

Licensed under an LGPL3 License  
Copyright 2021

## This PyPI Was Designed and Written By

[**The PySimpleGUI Project**](http://www.PySimpleGUI.com)

This program originated from the PySimpleGUI Demo Programs.  You'll find it here: 
[Demo_Make_Windows_Shortcut](https://github.com/PySimpleGUI/PySimpleGUI/blob/master/DemoPrograms/Demo_Image_Resize_and_Base64_Encode.pyw)  

Mike from PySimpleGUI.org 

## Contributing

Like the PySimpleGUI project, this project is currently licensed under an open-source license, the project itself is structured like a proprietary product. Pull Requests are not accepted.

## Copyright

Copyright 2021 PySimpleGUI

==> psgresizer-1.3.1.tar.gz: psgresizer-1.3.1/README.md <==

<p align="center">
  <img src="https://raw.githubusercontent.com/PySimpleGUI/PySimpleGUI/master/images/for_readme/Logo%20with%20text%20for%20GitHub%20Top.png" alt="Python GUIs for Humans">
  <h2 align="center">psgresizer</h2>
  <h2 align="center">A PySimpleGUI Application</h2>

</p>

Convert between formats, resize, and Base64 encode your images quickly and easily with this GUI application.  Resizes and encodes to Base64 so that the result can be pasted into your PySimpleGUI program for easy distribution of your applications without the need to distribute image files.


![image](https://raw.githubusercontent.com/PySimpleGUI/psgresizer/main/Screenshots/psgresizer.jpg)



## Installation

### Old-school Straight Pip

pip install psgresizer

### pip via `python -m pip` the python recommended way

#### If `python` is your command

python -m pip install psgresizer

#### If `python3` is your command

python3 -m pip install psgresizer

## Usage

Open a command window and type:   

`psgresizer`   


## Create a Shortcut To This Program

If you're a Windows user, then use the [`psgshortcut` application](https://pypi.org/project/psgshortcut/) to make a shortcut to this program so that you can then put on your desktop or pin to your taskbar (or any  other use that stops the need to type `psgresizer` ever again).

To get `psgshortcut`, like all of the other `psg application` projects, pip install it.  (e.g. `pip install psgshortcut`)



To do this, follow these steps:

1. Open a command window (I promise, it's the last time you'll need to for this program)
2. Type - `where psgresizer`
3. Copy the line that `where psgresizer` gave you into the first input of the shortcut maker program
4. Run psgresizer by typing `psgresizer` in your command window
5. Right click and choose "File Location"
6. Copy the file location results, but change the extension from .py to .ico and paste into the Icon file input of the shortcut maker
7. Click "Create Shortcut"

This will create a shortcut in the same folder as the target file.  You can safely move this shortcut file to any place you want (like to your desktop).  Double-click the shortcut and your program should launch.

## Release Notes

1.3.1 16-Nov-2021
* Added correct readme to PyPI Release

1.3.0 16-Nov-2021
* Finally getting around to adding release notes
* Added conversion feature
* Added version number
* Added live links to this repo and the PySimpleGUI project at the bottom of the window


## License

Licensed under an LGPL3 License  
Copyright 2021

## This PySimpleGUI Application Was Designed and Written By

[**The PySimpleGUI Project**](http://www.PySimpleGUI.com)

This program originated from the PySimpleGUI Demo Programs.  You'll find it here: 
[Demo_Make_Windows_Shortcut](https://github.com/PySimpleGUI/PySimpleGUI/blob/master/DemoPrograms/Demo_Image_Resize_and_Base64_Encode.pyw)  

Mike from PySimpleGUI.org 

## Contributing

Like the PySimpleGUI project, this project is currently licensed under an open-source license, the project itself is structured like a proprietary product. Pull Requests are not accepted.

## Copyright

Copyright 2021 PySimpleGUI
